/**
* Copyright (c) 2005, Freescale Semiconductor
* Freescale Willy Note
*
* File name : main.c
* Project name: Interrupts_QG8.mcp
*
* Author : Laura Delgado
* Department : RTAC Americas
*
* Description : This example illustrates the implementation of interrupts in 
*               CodeWarrior. This example makes use of the Device Initialization 
*               tool for the Timer module set up. The Timer module will trigger  
*               the interrupt routines to be used in this example. 
*               
*               For this example, the TPM (Timer/PWM) module is configured
*               to comply with the following requirements:
*                       + Timer configured as output compare, to toggle the 
*                           output (TPM0) when counter reaches compare value 
*                           0X0FFF.
*                           
*                       + Counter frequency at 3.81 Hz (bus clock selected as
*                           clock source, prescale value of 32, modulo counter 
*                           at 0x7FFF)
*                           
*                       + The selected channel output pin is PTA0/TPMCH0 and
*                           has no pull resistor.
*                       
*                       + Both, overflow and channel interrupts are enabled 
*                           to toggle a LED when their corresponding ISR 
*                           is serviced.
*                       
*                       +  PTB6 and PTB7 are initialized as outputs to control
*                            the LEDs                         
*                                                       
*               The initialization of the module is the Device Initialization tool 
*               automatically generated MCUinit.c code, which was included in this 
*               project.
*
*               This example was explicitly made for the MC9S08QG8 microcontroller 
*               migrating may need some changes in the code.
*           
*               (Refer to AN3136 for more information about Device Initialization)
* History :   
* 10/08/2005  : Release (r12370c)
*/

#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */

void MCU_init(void);


void main(void) {

  MCU_init();

  for(;;) {
  } /* loop forever */
}
 


void MCU_init(void) {
  /* ### MC9S08QG8_16 "Cpu" init code ... */
  /*  PE initialization code after reset */
  /*  System clock initialization */
  SOPT1 = 0x52;                                      
  SPMSC1 = 0x1C;                                      
  SPMSC2 = 0x00;                                      
  SPMSC3 &= (unsigned char)~0x30;                              
  ICSC1 = 0x04;                                      
  ICSC2 = 0x40;                                      
  /* Common initialization of the write once registers */
  SOPT2 = 0x00;                                      

  /* Common initialization of the CPU registers */
  PTASE |= (unsigned char)0x3F;                               
  PTBSE = 0xFF;                                      
  PTADS = 0x00;                                      
  PTBDS = 0x00;                                      
  /* ### Init_TPM init code */
  TPMMOD = 0x7FFF;                                      
  TPMC0V = 0x0FFF;                                      
  TPMC0SC = 0x50;                                      

  TPMSC = 0x4D;                                      
  /* ### Init_GPIO init code */
  PTBPE &= (unsigned char)~0xC0;                              
  PTBDD |= (unsigned char)0xC0;                               
  /* ### Init_COP init code */
  SRS = 0xFF;                                      

  /* ### */
  asm CLI;                             /* Enable interrupts */
} /*MCU_init*/


void interrupt 5 Vtpmch0_ISR (void) {

    TPMC0SC_CH0F = 0;   // ACK channel interrupt 
                        // Reading flag, then write a zero to the bit. 
    
    PTBD_PTBD6 = ~PTBD_PTBD6;

}

void interrupt 7 Vtpmovf_ISR(void){

    TPMSC_TOF = 0;      // ACK timer overflow interrupt 
                        // Reading flag, then write a zero to the bit.
                            
    PTBD_PTBD7 = ~PTBD_PTBD7;

}
